/**
	$Id: CustomRequestHandler.java 5446 2010-10-15 11:59:00Z nicklas $

	Copyright (C) 2010 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.jobagent.handlers;

import net.sf.basedb.clients.jobagent.Agent;
import net.sf.basedb.util.jobagent.RequestHandler;

/**
	An extension to the regular request-handler interface that allows
	life-cycle control by the job agent. Custom request handlers are
	typically defined in the job.properties configuration file. 
	They will automatically be create when the agent is started
	and closed when the agent is stopped.
	<p>
	
	Implementations must be thread-safe and be able to handle multiple requests
	at the same time.
	
	@author Nicklas
	@since 2.16
	@base.modified $Date: 2010-10-15 13:59:00 +0200 (fr, 15 okt 2010) $
*/
public interface CustomRequestHandler
	extends RequestHandler
{

	
	/**
		Initialize the request handler. This method is called once immediately
		after the object has been created.
		@param agent The agent 
		@since 2.16
	*/
	public void init(Agent agent);

	/**
		This method is called at when the agent is stopped.
		@since 2.16
	*/
	public void close();
	
}
