/*
	$Id $

	Copyright (C) 2014 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.authentication;

import net.sf.basedb.core.AuthenticationContext;
import net.sf.basedb.util.extensions.Action;
import net.sf.basedb.util.extensions.InvokationContext;

/**
	Action interface for external authentication. Action factories are called
	with a {@link AuthenticationContext} object as the {@link InvokationContext#getClientContext()}.
	
	Use {@link AuthenticationContext#getLoginRequest()} to get information about the login
	and password used for logging in.
	
	@author Nicklas
	@since 3.3
*/
public interface AuthenticationManager 
	extends Action
{

	/**
		Try to authenticate a user given the login information passed to
		the factory in the {@link AuthenticationContext}. There are three
		outcomes from this method:
		
		<ul>
		<li>The login request was valid: An {@link AuthenticationInformation} object should
			be returned with at least the external id of the user.
		<li>The login request was invalid: An {@link AuthenticationException} (or a
			subclass) should be thrown
		<li>It was not possible to know if the request was invalid or not: null should
			be returned to let the authentication continue with another action or internal
			authentication.
		</ul>
		
		@return An AuthenticationInformation object if the user 
			was authenticated, null if this action doesn't know if the login is
			valid or not
		@throws AuthenticationException If the user was not authenticated
	*/
	public AuthenticatedUser authenticate();
	
	
}
