/*
	$Id: PluginKeys.java 6127 2012-09-14 07:28:35Z nicklas $

	Copyright (C) 2006 Nicklas Nordborg, Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/

package net.sf.basedb.core.data.keyring;

import net.sf.basedb.core.PluginDefinition;

import java.io.Serializable;

/**
	Class for mapping the <code>PluginKeys</code> table.
	@author Martin, Nicklas
	@version 2.0
	@base.modified $Date: 2006-09-13 09:37:00Z $
*/
public class PluginKeys
	implements Serializable, Comparable<PluginKeys>
{
	/**
		
	*/
	private static final long serialVersionUID = -8514403856902670522L;

	private int pluginDefinitionId;
	
	private int keyId;
	
	private int granted;
	
	private int denied;
	
	/**
	 	Create new <code>PluginKeys</code> object
	*/
	public PluginKeys ()
	{}
	
	/**
	 	Gets the id of the plugin
	*/
	public int getPluginDefinitionId()
	{
		return pluginDefinitionId;
	}
	
	/**
	 	Sets the <code>PluginDefinition</code>:s ID
	  	@param pluginDefinitionId The ID of {@link PluginDefinition} to be set.
	*/
	public void setPluginDefinitionId(int pluginDefinitionId)
	{
		this.pluginDefinitionId = pluginDefinitionId;
	}
	
	/**
	  	Gets the id of the <code>RoleKey</code>
	*/
	public int getKeyId()
	{
		return keyId;
	}
	
	/**
	  	Sets the id of the <code>RoleKey</code> 
	  	@param keyId
	*/
	public void setKeyId(int keyId)
	{
		this.keyId = keyId;
	}
	
	/**
		Get the granted permissions.
	*/
	public final int getGranted()
	{
		return granted;
	}
	/**
		Set the granted permissions.
	*/
	public final void setGranted(int granted)
	{
		this.granted = granted;
	}
	
	/**
		Get the denied permissions.
	*/
	public final int getDenied()
	{
		return denied;
	}
	/**
		Set the denied permissions.
	*/
	public final void setDenied(int denied)
	{
		this.denied = denied;
	}	
	
	/**
		Check if this object is equal to another <code>RoleKeys</code>
		object. They are considered to be the same if the role id and the
		key id are the same. The permissions may be different.
	*/
	@Override
	public boolean equals(Object o)
	{
		if ((o == null) || (getClass() != o.getClass())) return false;
		PluginKeys pdk = (PluginKeys)o;
		return (pdk.pluginDefinitionId == this.pluginDefinitionId) && (pdk.keyId == this.keyId);
	}
	
	/**
		Calculate the hash code for the object.
	*/
	@Override
	public int hashCode()
	{
		return (int)(31*keyId + 17*pluginDefinitionId);
	}
	
	/**
		Compare the keyId of this object to the keyId of
		another <code>PluginKeys</code> object.
	*/
	@Override
	public final int compareTo(PluginKeys other)
	{
		return this.keyId - other.keyId;
	}	
}
