/**
	$Id: QueryWrapper.java 6472 2014-06-11 08:45:51Z nicklas $

	Copyright (C) Authors contributing to this file.

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.hibernate;

import java.io.Serializable;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.util.Calendar;
import java.util.Collection;
import java.util.Date;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.Map;

import org.hibernate.CacheMode;
import org.hibernate.FlushMode;
import org.hibernate.HibernateException;
import org.hibernate.LockMode;
import org.hibernate.LockOptions;
import org.hibernate.Query;
import org.hibernate.ScrollMode;
import org.hibernate.ScrollableResults;
import org.hibernate.transform.ResultTransformer;
import org.hibernate.type.Type;

/**
	A simple wrapper around hibernate queries which simply forwards 
	all calls to a parent query.
	
	@author nicklas
	@version 2.5
	@base.modified $Date: 2014-06-11 10:45:51 +0200 (on, 11 jun 2014) $
*/
public class QueryWrapper
	implements Query
{

	protected final Query query;
	
	public QueryWrapper(Query query)
	{
		this.query = query;
	}
	
	@Override
	public int executeUpdate()
		throws HibernateException
	{
		return query.executeUpdate();
	}

	@Override
	public String[] getNamedParameters() 
		throws HibernateException
	{
		return query.getNamedParameters();
	}

	@Override
	public String getQueryString()
	{
		return query.getQueryString();
	}

	@Override
	public String[] getReturnAliases() 
		throws HibernateException
	{
		return query.getReturnAliases();
	}

	@Override
	public Type[] getReturnTypes() 
		throws HibernateException
	{
		return query.getReturnTypes();
	}

	@Override
	public boolean isReadOnly()
	{
		return query.isReadOnly();
	}

	@Override
	public Iterator iterate() 
		throws HibernateException
	{
		return query.iterate();
	}

	@Override
	public List list() 
		throws HibernateException
	{
		return query.list();
	}

	@Override
	public ScrollableResults scroll() 
		throws HibernateException
	{
		return query.scroll();
	}

	@Override
	public ScrollableResults scroll(ScrollMode scrollMode)
		throws HibernateException
	{
		return query.scroll(scrollMode);
	}

	@Override
	public Query setBigDecimal(int position, BigDecimal number)
	{
		query.setBigDecimal(position, number);
		return this;
	}

	@Override
	public Query setBigDecimal(String name, BigDecimal number)
	{
		query.setBigDecimal(name, number);
		return this;
	}

	@Override
	public Query setBigInteger(int position, BigInteger number)
	{
		query.setBigInteger(position, number);
		return this;
	}

	@Override
	public Query setBigInteger(String name, BigInteger number)
	{
		query.setBigInteger(name, number);
		return this;
	}

	@Override
	public Query setBinary(int position, byte[] val)
	{
		query.setBinary(position, val);
		return this;
	}

	@Override
	public Query setBinary(String name, byte[] val)
	{
		query.setBinary(name, val);
		return this;
	}

	@Override
	public Query setBoolean(int position, boolean val)
	{
		query.setBoolean(position, val);
		return this;
	}

	@Override
	public Query setBoolean(String name, boolean val)
	{
		query.setBoolean(name, val);
		return this;
	}

	@Override
	public Query setByte(int position, byte val)
	{
		query.setByte(position, val);
		return this;
	}

	@Override
	public Query setByte(String name, byte val)
	{
		query.setByte(name, val);
		return this;
	}

	@Override
	public Query setCacheMode(CacheMode cacheMode)
	{
		query.setCacheMode(cacheMode);
		return this;
	}

	@Override
	public Query setCacheRegion(String cacheRegion)
	{
		query.setCacheRegion(cacheRegion);
		return this;
	}

	@Override
	public Query setCacheable(boolean cacheable)
	{
		query.setCacheable(cacheable);
		return this;
	}

	@Override
	public Query setCalendar(int position, Calendar calendar)
	{
		query.setCalendar(position, calendar);
		return this;
	}

	@Override
	public Query setCalendar(String name, Calendar calendar)
	{
		query.setCalendar(name, calendar);
		return this;
	}

	@Override
	public Query setCalendarDate(int position, Calendar calendar)
	{
		query.setCalendarDate(position, calendar);
		return this;
	}

	@Override
	public Query setCalendarDate(String name, Calendar calendar)
	{
		query.setCalendarDate(name, calendar);
		return this;
	}

	@Override
	public Query setCharacter(int position, char val)
	{
		query.setCharacter(position, val);
		return this;
	}

	@Override
	public Query setCharacter(String name, char val)
	{
		query.setCharacter(name, val);
		return this;
	}

	@Override
	public Query setComment(String comment)
	{
		query.setComment(comment);
		return this;
	}

	@Override
	public Query setDate(int position, Date date)
	{
		query.setDate(position, date);
		return this;
	}

	@Override
	public Query setDate(String name, Date date)
	{
		query.setDate(name, date);
		return this;
	}

	@Override
	public Query setDouble(int position, double val)
	{
		query.setDouble(position, val);
		return this;
	}

	@Override
	public Query setDouble(String name, double val)
	{
		query.setDouble(name, val);
		return this;
	}

	@Override
	public Query setEntity(int position, Object val)
	{
		query.setEntity(position, val);
		return this;
	}

	@Override
	public Query setEntity(String name, Object val)
	{
		query.setEntity(name, val);
		return this;
	}

	@Override
	public Query setFetchSize(int fetchSize)
	{
		query.setFetchSize(fetchSize);
		return this;
	}

	@Override
	public Query setFirstResult(int firstResult)
	{
		query.setFirstResult(firstResult);
		return this;
	}

	@Override
	public Query setFloat(int position, float val)
	{
		query.setFloat(position, val);
		return this;
	}

	@Override
	public Query setFloat(String name, float val)
	{
		query.setFloat(name, val);
		return this;
	}

	@Override
	public Query setFlushMode(FlushMode flushMode)
	{
		query.setFlushMode(flushMode);
		return this;
	}

	@Override
	public Query setInteger(int position, int val)
	{
		query.setInteger(position, val);
		return this;
	}

	@Override
	public Query setInteger(String name, int val)
	{
		query.setInteger(name, val);
		return this;
	}

	@Override
	public Query setLocale(int position, Locale locale)
	{
		query.setLocale(position, locale);
		return this;
	}

	@Override
	public Query setLocale(String name, Locale locale)
	{
		query.setLocale(name, locale);
		return this;
	}

	@Override
	public Query setLockMode(String alias, LockMode lockMode)
	{
		query.setLockMode(alias, lockMode);
		return this;
	}
	
	@Override
	public Query setLockOptions(LockOptions lockOptions)
	{
		query.setLockOptions(lockOptions);
		return this;
	}

	@Override
	public Query setLong(int position, long val)
	{
		query.setLong(position, val);
		return this;
	}

	@Override
	public Query setLong(String name, long val)
	{
		query.setLong(name, val);
		return this;
	}

	@Override
	public Query setMaxResults(int maxResults)
	{
		query.setMaxResults(maxResults);
		return this;
	}

	@Override
	public Query setParameter(int position, Object val)
		throws HibernateException
	{
		query.setParameter(position, val);
		return this;
	}

	@Override
	public Query setParameter(String name, Object val) 
		throws HibernateException
	{
		query.setParameter(name, val);
		return this;
	}

	@Override
	public Query setParameter(int position, Object val, Type type)
	{
		query.setParameter(position, val, type);
		return this;
	}

	@Override
	public Query setParameter(String name, Object val, Type type)
	{
		query.setParameter(name, val, type);
		return this;
	}

	@Override
	public Query setParameterList(String name, Collection vals)
		throws HibernateException
	{
		query.setParameterList(name, vals);
		return this;
	}

	@Override
	public Query setParameterList(String name, Object[] vals)
		throws HibernateException
	{
		query.setParameterList(name, vals);
		return this;
	}

	@Override
	public Query setParameterList(String name, Collection vals, Type type)
		throws HibernateException
	{
		query.setParameterList(name, vals, type);
		return this;
	}

	@Override
	public Query setParameterList(String name, Object[] vals, Type type)
		throws HibernateException
	{
		query.setParameterList(name, vals, type);
		return this;
	}

	@Override
	public Query setParameters(Object[] values, Type[] types)
		throws HibernateException
	{
		query.setParameters(values, types);
		return this;
	}

	@Override
	public Query setProperties(Object bean) 
		throws HibernateException
	{
		query.setProperties(bean);
		return this;
	}

	@Override
	public Query setProperties(Map bean) 
		throws HibernateException
	{
		query.setProperties(bean);
		return this;
	}

	@Override
	public Query setReadOnly(boolean readOnly)
	{
		query.setReadOnly(readOnly);
		return this;
	}

	@Override
	public Query setResultTransformer(ResultTransformer transformer)
	{
		query.setResultTransformer(transformer);
		return this;
	}

	@Override
	public Query setSerializable(int position, Serializable val)
	{
		query.setSerializable(position, val);
		return this;
	}

	@Override
	public Query setSerializable(String name, Serializable val)
	{
		query.setSerializable(name, val);
		return this;
	}

	@Override
	public Query setShort(int position, short val)
	{
		query.setShort(position, val);
		return this;
	}

	@Override
	public Query setShort(String name, short val)
	{
		query.setShort(name, val);
		return this;
	}

	@Override
	public Query setString(int position, String val)
	{
		query.setString(position, val);
		return this;
	}

	@Override
	public Query setString(String name, String val)
	{
		query.setString(name, val);
		return this;
	}

	@Override
	public Query setText(int position, String val)
	{
		query.setText(position, val);
		return this;
	}

	@Override
	public Query setText(String name, String val)
	{
		query.setText(name, val);
		return this;
	}

	@Override
	public Query setTime(int position, Date date)
	{
		query.setTime(position, date);
		return this;
	}

	@Override
	public Query setTime(String name, Date date)
	{
		query.setTime(name, date);
		return this;
	}

	@Override
	public Query setTimeout(int timeout)
	{
		query.setTimeout(timeout);
		return this;
	}

	@Override
	public Query setTimestamp(int position, Date date)
	{
		query.setTimestamp(position, date);
		return this;
	}

	@Override
	public Query setTimestamp(String name, Date date)
	{
		query.setTimestamp(name, date);
		return this;
	}

	@Override
	public Object uniqueResult() 
		throws HibernateException
	{
		return query.uniqueResult();
	}

	@Override
	public FlushMode getFlushMode() 
	{
		return query.getFlushMode();
	}

	@Override
	public CacheMode getCacheMode() 
	{
		return query.getCacheMode();
	}

	@Override
	public boolean isCacheable() 
	{
		return query.isCacheable();
	}

	@Override
	public String getCacheRegion() 
	{
		return query.getCacheRegion();
	}

	@Override
	public Integer getTimeout() 
	{
		return query.getTimeout();
	}

	@Override
	public Integer getFetchSize() 
	{
		return query.getFetchSize();
	}

	@Override
	public Integer getMaxResults() 
	{
		return query.getMaxResults();
	}

	@Override
	public Integer getFirstResult() 
	{
		return query.getFirstResult();
	}

	@Override
	public LockOptions getLockOptions() 
	{
		return query.getLockOptions();
	}

	@Override
	public String getComment() 
	{
		return query.getComment();
	}

	@Override
	public Query addQueryHint(String hint) 
	{
		query.addQueryHint(hint);
		return this;
	}

}
