/**
	$Id: TableInfoWork.java 6468 2014-06-10 11:27:02Z nicklas $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.hibernate;

import java.sql.Connection;
import java.sql.DatabaseMetaData;
import java.sql.SQLException;

import org.hibernate.jdbc.ReturningWork;
import org.hibernate.mapping.Table;

import net.sf.basedb.core.dbengine.TableInfo;

/**
	A work implementation that loads database metadata for a table
	and returns it as a {@link TableInfo} object.

	@author nicklas
	@version 2.9
	@base.modified $Date: 2014-06-10 13:27:02 +0200 (ti, 10 jun 2014) $
*/
public class TableInfoWork
	implements ReturningWork<TableInfo>
{

	private final Table table;
	
	/**
		Create a new work item.
		@param table The table to get metadata information about
	 */
	public TableInfoWork(Table table)
	{
		this.table = table;
	}
	
	/**
		From the Work interface
		-----------------------
	*/
	@Override
	public TableInfo execute(Connection connection) 
		throws SQLException
	{
		DatabaseMetaData metaData = connection.getMetaData();
		return new TableInfo(table, metaData);
	}
	// --------------------------

}
