/**
	$Id $

	Copyright (C) 2014 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.signal;

import net.sf.basedb.core.Application;
import net.sf.basedb.util.extensions.ClientContext;
import net.sf.basedb.util.extensions.ExtensionsFilter;
import net.sf.basedb.util.extensions.ExtensionsInvoker;
import net.sf.basedb.util.extensions.Registry;
import net.sf.basedb.util.extensions.Renderer;
import net.sf.basedb.util.extensions.manager.ExtensionsManager;

/**
	A signal transporter implementation send all signals to extensions
	extending the "net.sf.basedb.core.signal" extension point. The
	initialization parameter for the transporter must be a valid URI.
	The URI is set as "signal-uri" attribute in the {@link ClientContext}.
	
	@author nicklas
	@since 3.3
*/
public class ExtensionSignalTransporter 
	extends AbstractSignalTransporter
{

	private static final org.slf4j.Logger logger = 
		org.slf4j.LoggerFactory.getLogger(ExtensionSignalTransporter.class);
	
	private ClientContext context;
	private String extensionPointId = "net.sf.basedb.core.signal";
	
	public ExtensionSignalTransporter()
	{}
	
	/*
		From the SignalTransporter interface
		-------------------------------------------
	*/
	@SuppressWarnings("unchecked")
	@Override
	public void send(Signal signal)
	{
		logger.info("Sending signal " + signal.getId() + " to " + getGlobalSignalId());
		
		// Load extensions
		ExtensionsManager manager = Application.getExtensionsManager();
		ExtensionsFilter filter = manager.getSettings();
		Registry registry = manager.getRegistry();
		if (context == null) context = new ClientContext();
		context.setAttribute("signal-uri", getSignalURI());
		context.setAttribute("signal", signal);
		ExtensionsInvoker<SignalHandler> invoker = (ExtensionsInvoker<SignalHandler>)registry.useExtensions(context, filter, extensionPointId);
		
		// Send the signal
		logger.debug("Found " + invoker.getNumExtensions() + " extensions for " + getGlobalSignalId());
		invoker.render(new SendSignalRenderer(signal));
	}
	// ---------------------------------------------
	
	
	public void setContext(ClientContext context)
	{
		this.context = context;
	}
	
	public void setExtensionPointId(String extensionPointId)
	{
		this.extensionPointId = extensionPointId;
	}
	
	static class SendSignalRenderer
		implements Renderer<SignalHandler>
	{
		private final Signal signal;

		SendSignalRenderer(Signal signal)
		{
			this.signal = signal;
		}
		
		@Override
		public void render(SignalHandler action) 
		{
			if (logger.isDebugEnabled()) logger.debug("Sending signal " + signal.getId() + " to action " + action);
			action.handleSignal(signal);
		}
		
	}
}
