/*
	$Id: NestedIterator.java 6127 2012-09-14 07:28:35Z nicklas $

	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util;

import java.util.Collection;
import java.util.Iterator;
import java.util.NoSuchElementException;

/**
	This class implements the {@link Iterator} interface
	for iterating multiple collections as if it was one big collection. 

	@author Nicklas
	@version 2.0
	@base.modified $Date: 2012-09-14 09:28:35 +0200 (fr, 14 sep 2012) $
*/
public class NestedIterator<E>
	implements Iterator<E>
{
	/**
		The array to iterate.
	*/
	private final Collection<? extends E>[] collections;

	/**
		The index of the next collection to return.
	*/
	private int index;
	
	/**
		The current iterator.
	*/
	private Iterator<? extends E> current;

	/**
		Create a new <code>ArrayIterator</code> object.
	 	@param collections An array of Collection objects. 
	*/
	@SafeVarargs
	public NestedIterator(Collection<? extends E>... collections)
	{
		this.collections = collections;
		this.current = null;
		this.index = 0;
	}
	@Override
	public boolean hasNext()
	{
		if (collections == null) return false;
		boolean next = false;
		boolean atEnd = false;
		while (!next && !atEnd)
		{
			if (current == null) 
			{
				if (index < collections.length)
				{
					Collection<? extends E> c = collections[index];
					if (c != null)	current = c.iterator();
					index++;
				}
				else
				{
					atEnd = true;
				}
			}
			if (current != null) 
			{
				next = current.hasNext();
				if (!next) current = null;
			}
		}
		return next;
	}
	@Override
	public E next()
	{
		if (!hasNext()) throw new NoSuchElementException();
		return current.next();
	}
	/**
		This operation is not supported.
		@throws UnsupportedOperationException Is always thrown
	*/
	@Override
	public void remove()
	{
		throw new UnsupportedOperationException();
	}
}
