/**
	$Id: InstanceOfFilter.java 4594 2008-10-21 07:20:40Z nicklas $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.filter;

/**
	A filter implementation that accepts all objects
	that are (sub)classes of a specified class.
	
	@author Nicklas
	@version 2.9
	@base.modified $Date: 2008-10-21 09:20:40 +0200 (ti, 21 okt 2008) $
*/
public class InstanceOfFilter<T>
	implements Filter<T>
{
	
	private final Class<?> clazz;
	private final boolean allowSubclass;
	/**
		Create a new filter. 
		@param clazz The class to match against
		@param allowSubclass If subclasses to the specified class should
			be accepted (TRUE) or denied (FALSE)
	*/
	public InstanceOfFilter(Class<?> clazz, boolean allowSubclass)
	{
		this.clazz = clazz;
		this.allowSubclass = allowSubclass;
	}

	/**
		@return TRUE if the object is an instance of the given class, FALSE otherwise
	*/
	@Override
	public boolean evaluate(T object)
	{
		return allowSubclass ? 
			clazz.isInstance(object) : 
			object != null && object.getClass() == clazz;
	}
	
}
