/**
	$Id: ASTConstantConverter.java 4515 2008-09-11 20:08:14Z jari $

	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.jep.convert;

import net.sf.basedb.core.BaseException;
import net.sf.basedb.core.query.Expression;

import org.nfunk.jep.ASTConstant;

/**
	Converts a constant node to an expression.

	@author nicklas
	@version 2.4
	@base.modified $Date: 2008-09-11 22:08:14 +0200 (to, 11 sep 2008) $
*/
public class ASTConstantConverter
	extends AbstractJepConversionFunction<ASTConstant>
{
	
	public ASTConstantConverter()
	{}
	
	/*
		From the JepConversionFunction interface
		-------------------------------------------
	*/
	/**
		Get the value from the constant node and check the {@link ConverterFactory} for
		a registered converter for the class and use it.
		@return An expression or null if the value is null
		@throws BaseException If the node can't be converted
	*/
	@SuppressWarnings("unchecked")
	@Override
	public Expression toExpression(ASTConstant node)
	{
		Expression e = null;
		Object value = node.getValue();
		if (value != null)
		{
			JepConversionFunction converter = ConverterFactory.getConverterByClass(value);
			if (converter != null)
			{
				e = converter.toExpression(value);
			}
			if (e == null)
			{
				throw new BaseException("Unsupported JEP constant: " + value.getClass().getName());
			}
		}
		return e;
	}
	// -------------------------------------------

}
