/*
	$Id: TestParameterType.java 4889 2009-04-06 12:52:39Z nicklas $

	Copyright (C) 2005 Samuel Andersson, Johan Enell, Nicklas Nordborg
	Copyright (C) 2006 Johan Enell, Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
import net.sf.basedb.core.BaseException;
import net.sf.basedb.core.DateParameterType;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.FileParameterType;
import net.sf.basedb.core.FloatParameterType;
import net.sf.basedb.core.IntegerParameterType;
import net.sf.basedb.core.InvalidDataException;
import net.sf.basedb.core.ItemParameterType;
import net.sf.basedb.core.News;
import net.sf.basedb.core.ParameterType;
import net.sf.basedb.core.StringParameterType;
import net.sf.basedb.core.data.IntegerParameterValueData;

import java.util.List;
import java.util.ArrayList;
import java.util.Arrays;

public class TestParameterType
{

	static boolean ok = true;
	public static void main(String[] args)
	{
		TestUtil.checkArgs(args);
		TestUtil.begin();
		ok = test_all();
		TestUtil.stop();
	}

	static boolean test_all()
	{
		write("++Testing parameter types");
		// Standard tests: create, load, list
		int newsId = TestNews.test_create(true);
		int newsId2 = TestNews.test_create(true);
		List<ParameterType> parameters = test_create(newsId);
		test_validation(parameters, newsId, newsId2);
		test_list(parameters);
		if (TestUtil.waitBeforeDelete()) TestUtil.waitForEnter();
		TestNews.test_delete(newsId2);
		TestNews.test_delete(newsId);

		write("++Testing parameter types "+(ok ? "OK" : "Failed")+"\n");
		return ok;
	}

	static List<ParameterType> test_create(int newsId)
	{
		List<ParameterType> parameters = new ArrayList<ParameterType>();
		IntegerParameterType intType = new IntegerParameterType(null, 100, null, false);
		parameters.add(intType);
		
		FloatParameterType floatType = new FloatParameterType(null, 234.324F, null, false);
		parameters.add(floatType);

		DateParameterType dateType = new DateParameterType();
		parameters.add(dateType);
		
		StringParameterType stringType = new StringParameterType(37, "nothing", false);
		parameters.add(stringType);

		FileParameterType fileType = new FileParameterType();
		parameters.add(fileType);

		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();
			
			ItemParameterType<News> itemType = new ItemParameterType<News>(News.class, Arrays.asList(News.getById(dc, newsId)));
			parameters.add(itemType);
		}
		catch (Throwable ex)
		{
			write("--Load MIME types FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
		
		return parameters;
	}
	
	@SuppressWarnings("unchecked")
	static void test_validation(List<ParameterType> parameters, int newsId, int newsId2)
	{
		try
		{
			for (ParameterType param : parameters)
			{
				if (param instanceof IntegerParameterType)
				{
					IntegerParameterValueData intValue = new IntegerParameterValueData();
					intValue.getValues().add(100);
					param.validate("integer", intValue.getValues());
					param.validate("integer", new Integer(-234));
					
					// Testing with wrong value
					boolean valid = true;
					try
					{
						param.validate("integer", new Integer(101));
					}
					catch (InvalidDataException ex)
					{
						valid = false;
					}
					if (valid) // Should not be valid
					{
						throw new BaseException();
					}
				}
				else if (param instanceof FloatParameterType)
				{
					param.validate("float", new Float(50.0f));
				}
				else if (param instanceof StringParameterType)
				{
					param.validate("string", "The bear was walking down the stairs.");
					
					// Testing with wrong value
					boolean valid = true;
					try
					{
						param.validate("float", "Running like a fool, but still no response." );
					}
					catch (InvalidDataException ex)
					{
						valid = false;
					}
					if (valid) // Should not be valid
						throw new BaseException();
				}
				else if (param instanceof ItemParameterType)
				{
					DbControl dc = null;
					try
					{
						dc = TestUtil.getDbControl();
						News n = News.getById(dc, newsId);
						param.validate("news", n);
						
						// Testing with wrong value
						boolean valid = true;
						News n2 = News.getById(dc, newsId2);
						try
						{
							param.validate("news", n2);
						}
						catch (InvalidDataException ex)
						{
							valid = false;
						}
						if (valid) // Should not be valid
							throw new BaseException();
					}
					finally
					{
						if (dc != null) dc.close();
					}
				}
			}
			write("--Testing parameter type validation OK");
		}
		catch (Throwable ex)
		{
			ok = false;
			write("--Testing parameter type validation FAILED");
			ex.printStackTrace();
		}
	}
	
	static void test_list(List<ParameterType> parameters)
	{
		if (!TestUtil.getSilent())
		{
			write("List parameter types");
			write("--------------------");
			for (ParameterType param : parameters)
			{
				write(param.toString());
			}
		}
	}

	static void write(String message)
	{
		System.out.println(message);
	}
}

