<%-- $Id: view_feature.jsp 6520 2014-08-18 11:29:37Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2006 Johan Enell, Jari Häkkinen, Nicklas Nordborg
	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.SystemItems"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.ExtendedProperties"
	import="net.sf.basedb.core.ExtendedProperty"
	import="net.sf.basedb.core.ArrayDesign"
	import="net.sf.basedb.core.ArrayDesignBlock"
	import="net.sf.basedb.core.Feature"
	import="net.sf.basedb.core.ReporterType"
	import="net.sf.basedb.core.Reporter"
	import="net.sf.basedb.core.Plate"
	import="net.sf.basedb.core.Well"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.core.PluginDefinition"
	import="net.sf.basedb.core.data.FeatureData"
	import="net.sf.basedb.core.data.ReporterData"
	import="net.sf.basedb.core.plugin.GuiContext"
	import="net.sf.basedb.core.plugin.Plugin"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.util.formatter.Formatter"
	import="net.sf.basedb.util.formatter.WellCoordinateFormatter"
	import="net.sf.basedb.clients.web.formatter.FormatterFactory"
	import="java.util.Date"
	import="java.util.Map"
	import="java.util.Set"
	import="java.util.List"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="t" uri="/WEB-INF/tab.tld" %>
<%@ taglib prefix="tbl" uri="/WEB-INF/table.tld" %>
<%!
	private static final Item itemType = Item.FEATURE;
	private static final GuiContext guiContext = new GuiContext(itemType, GuiContext.Type.ITEM);
%>
<%
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final String ID = sc.getId();
final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, null);
final int itemId = cc.getId();
final int arrayDesignId = Values.getInt(request.getParameter("arraydesign_id"));
final float scale = Base.getScale(sc);
final DbControl dc = sc.newDbControl();
try
{
	Formatter<Date> dateTimeFormatter = FormatterFactory.getDateTimeFormatter(sc);
	Formatter<Date> dateFormatter = FormatterFactory.getDateFormatter(sc);
	WellCoordinateFormatter rowFormatter = new WellCoordinateFormatter(true);
	WellCoordinateFormatter columnFormatter = new WellCoordinateFormatter(false);
	Map<Plugin.MainType, Integer> pluginCount = PluginDefinition.countPlugins(dc, guiContext);

	final ArrayDesign design = ArrayDesign.getById(dc, arrayDesignId);
	FeatureData feature = design.getFeatureById(itemId, true);
	ReporterData reporter = feature.getReporter();

	ArrayDesignBlock block = Feature.getArrayDesignBlock(dc, feature);
	
	Well well = null;
	boolean readWell = true;
	try
	{
		well = Feature.getWell(dc, feature);
	}
	catch (PermissionDeniedException ex)
	{
		readWell = false;
	}

	String title = "Feature of "+HTML.encodeTags(design.getName()) + " at position " + feature.getPosition();
	%>
	<base:page title="<%=title%>" type="popup" id="view-page">
	<base:head scripts="tabcontrol-2.js,~features.js" styles="tabcontrol.css">
	</base:head>
	<base:body data-read-only="1">
		<h1><%=title%> <base:help helpid="feature.view.properties" /></h1>

		<t:tabcontrol id="feature" 
			subclass="content dialogtabcontrol"
			position="bottom">
		<t:tab id="feat" title="Feature">
		
			<table class="fullform outlined">
			<tbody class="sectionheader">
				<tr>
					<th colspan="6">Array design</th>
				</tr>
			</tbody>
			<tbody>
			<tr>
				<th>Name</th>
				<td colspan="5"><%=HTML.encodeTags(design.getName())%></td>
			</tr>
			<tr>
				<th>Platform / Variant</th>
				<td colspan="5"><base:propertyvalue item="<%=design%>" property="platform" enablePropertyLink="false"/> / <base:propertyvalue item="<%=design%>" property="variant" enablePropertyLink="false"/></td>
			</tr>
			<tr>
				<th>Feature identification method</th>
				<td colspan="5"><%=design.getFeatureIdentificationMethod()%></td>
			</tr>
			</tbody>
			
			<tbody class="sectionheader">
				<tr>
					<th colspan="6">Feature / block</th>
				</tr>
			</tbody>
			
			<tbody>
			<tr>
				<th>Feature ID</th>
				<td><%=HTML.encodeTags(feature.getExternalId())%></td>
				<th class="leftborder">Reporter</th>
				<td><%=reporter == null ? "<i>- none -</i>" : HTML.encodeTags(reporter.getName())%></td>
				<th class="leftborder">Diameter</th>
				<td><%=block.getFeatureDiameter()%></td>
			</tr>
			<tr>
				<th>Position</th>
				<td><%=feature.getPosition()%></td>
				<th class="leftborder">Meta grid X</th>
				<td><%=block.getMetaGridX()%></td>
				<th class="leftborder">Meta grid Y</th>
				<td><%=block.getMetaGridY()%></td>
			</tr>
			<tr>
				<th>Block number</th>
				<td><%=block.getBlockNumber()%></td>
				<th class="leftborder">Block size X</th>
				<td><%=block.getBlockSizeX()%></td>
				<th class="leftborder">Block size Y</th>
				<td><%=block.getBlockSizeY()%></td>
			</tr>
			<tr>
				<th>Row</th>
				<td><%=feature.getRow()%></td>
				<th class="leftborder">Origin X</th>
				<td><%=block.getOriginX()%></td>
				<th class="leftborder">Origin Y</th>
				<td><%=block.getOriginY()%></td>
			</tr>
			<tr>
				<th>Column</th>
				<td><%=feature.getColumn()%></td>
				<th class="leftborder">Spacing X</th>
				<td><%=block.getSpacingX()%></td>
				<th class="leftborder">Spacing Y</th>
				<td><%=block.getSpacingY()%></td>
			</tr>
			</tbody>
			
			<tbody class="sectionheader">
				<tr>
					<th colspan="6">Plage / well</th>
				</tr>
			</tbody>
			
			<tbody>
				<%
				if (!readWell)
				{
					%>
					<tr>
						<th>Plate</th>
						<td colspan="5"><i>- denied -</i></td>
					</tr>
					<%
				}
				else if (well == null)
				{
					%>
					<tr>
						<th>Plate</th>
						<td colspan="5"><i>- none -</i></td>
					</tr>
					<%
				}
				else
				{
					Plate plate = well.getPlate();
					%>
					<tr>
						<th>Plate</th>
						<td colspan="5"><%=HTML.encodeTags(plate.getName())%></td>
					</tr>
					<tr>
						<th>Well</th>
						<td colspan="5"><%=rowFormatter.format(well.getRow())%><%=columnFormatter.format(well.getColumn())%></td>
					</tr>
					<%
				}
				%>
				<tr class="dynamic">
					<th></th>
					<td colspan="5"></td>
				</tr>
			</tbody>
			</table>
			
		</t:tab>
		
		<%
		if (reporter != null)
		{
			boolean readCurrentReporterType = true;
			ReporterType currentReporterType = null;
			try
			{
				currentReporterType = Reporter.getReporterType(dc, reporter);
			}
			catch (PermissionDeniedException ex)
			{
				readCurrentReporterType = false;
			}
			%>
			<t:tab id="reporter" title="Reporter" >
				<table class="fullform outlined">
				<tbody class="sectionheader">
					<tr>
						<th colspan="4">Common reporter properties</th>
					</tr>
				</tbody>
				<tbody>
				
				<tr>
					<th>Name</th>
					<td><%=HTML.encodeTags(reporter.getName())%></td>
					<th class="leftborder">External ID</th>
					<td><%=HTML.encodeTags(reporter.getExternalId())%></td>
				</tr>
				<tr>
					<th>Gene symbol</th>
					<td><%=HTML.encodeTags(reporter.getSymbol())%></td>
					<th class="leftborder">Type</th>
					<td><%=Base.getEncodedName(currentReporterType, !readCurrentReporterType)%></td>
				</tr>
				<tr>
					<th>Last update</th>
					<td><%=dateFormatter.format(reporter.getLastUpdate())%></td>
					<th class="leftborder">from/by</th>
					<td><%=reporter.getLastSource() %></td>
				</tr>
				<tr>
					<th>Description</th>
					<td colspan="3"><%=HTML.niceFormat(reporter.getDescription())%></td>
				</tr>
				</tbody>
				
				<tbody class="sectionheader">
					<tr>
						<th colspan="4">Extended reporter properties</th>
					</tr>
				</tbody>
				<tbody>
					<%
						List<ExtendedProperty> reporterProperties = ExtendedProperties.getProperties("ReporterData");
						if (reporterProperties != null)
						{
							boolean needsTr = true;
							for (ExtendedProperty ep : reporterProperties)
							{
								String name = ep.getName();
								Formatter f = FormatterFactory.getExtendedPropertyFormatter(sc, ep);
								String value = f.format(reporter.getExtended(name));
								%>
									<%=needsTr ? "<tr><th>" : "<th class=\"leftborder\">" %><%=HTML.encodeTags(ep.getTitle())%></th>
									<td><%=value%></td>
									<%=needsTr ? "" : "</tr>"%>
								<%
								needsTr = !needsTr;
							}
							%>
							<%=needsTr ? "" : "<th class=\"leftborder\"></th><td></td></tr>"%>
							<%
						}
						%>
					<tr class="dynamic">
						<th></th>
						<td></td>
						<th class="leftborder"></th>
						<td></td>
					</tr>
				</tbody>
				</table>
			</t:tab>
			<%
		}
		%>
		</t:tabcontrol>

		<base:buttongroup subclass="dialogbuttons">
			<base:button id="close" title="Close" />
		</base:buttongroup>
		
	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}

%>
